==> deltaspike-1.9.6-source-release.zip: deltaspike-1.9.6/deltaspike/modules/partial-bean/impl/src/test/java/org/apache/deltaspike/test/core/api/partialbean/uc013/SimpleCacheInterceptor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.deltaspike.test.core.api.partialbean.uc013;

import java.io.Serializable;
import javax.inject.Inject;
import javax.interceptor.AroundInvoke;
import javax.interceptor.Interceptor;
import javax.interceptor.InvocationContext;

@Interceptor
@SimpleCache
public class SimpleCacheInterceptor implements Serializable
{
    @Inject
    private SimpleCacheManager scm;
    
    @AroundInvoke
    public Object wrapBeanCandidate(InvocationContext invocationContext) throws Exception
    {
        if (scm.getSingletonCache().containsKey(invocationContext.getMethod()))
        {
            return scm.getSingletonCache().get(invocationContext.getMethod());
        }
        
        Object result = invocationContext.proceed();
        scm.getSingletonCache().put(invocationContext.getMethod(), result);
        
        return result;
    }
}

==> deltaspike-2.0.1-source-release.zip: deltaspike-2.0.1/deltaspike/modules/partial-bean/impl/src/test/java/org/apache/deltaspike/test/core/api/partialbean/uc013/SimpleCacheInterceptor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.deltaspike.test.core.api.partialbean.uc013;

import java.io.Serializable;
import jakarta.inject.Inject;
import jakarta.interceptor.AroundInvoke;
import jakarta.interceptor.Interceptor;
import jakarta.interceptor.InvocationContext;

@Interceptor
@SimpleCache
public class SimpleCacheInterceptor implements Serializable
{
    @Inject
    private SimpleCacheManager scm;
    
    @AroundInvoke
    public Object wrapBeanCandidate(InvocationContext invocationContext) throws Exception
    {
        if (scm.getSingletonCache().containsKey(invocationContext.getMethod()))
        {
            return scm.getSingletonCache().get(invocationContext.getMethod());
        }
        
        Object result = invocationContext.proceed();
        scm.getSingletonCache().put(invocationContext.getMethod(), result);
        
        return result;
    }
}
